documentationtools.ReSTDocument
===============================

.. abjad-lineage:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument

.. autoclass:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.children
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.leaves
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.node_klass
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.nodes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.rest_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.append
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.extend
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.index
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.insert
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.pop
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__contains__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__delitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__getitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__getstate__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__iter__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__len__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__setitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDocument.ReSTDocument.ReSTDocument.__setstate__
   :noindex:
